# frozen_string_literal: true

require 'codebot/payload'
require 'codebot/formatters'

module Codebot
  # An IRC message generated by a {Request} and sent to a {Channel}.
  class Message
    # @return [Channel] the channel to send this message to
    attr_reader :channel

    # @return [Symbol] the event that caused this message to be sent
    attr_reader :event

    # @return [Payload] the parsed request payload
    attr_reader :payload

    # Constructs a new message for delivery to an IRC channel.
    #
    # @param channel [Channel] the channel to send this message to
    # @param event [Symbol] the event that caused this message to be sent
    # @param payload [Payload] the parsed request payload
    def initialize(channel, event, payload, integration)
      @channel = channel
      @event   = event
      @payload = payload
      @integration = integration
    end

    # Formats this message for delivery to an IRC channel.
    #
    # @return [Array<String>] the formatted IRC messages
    def format
      Formatters.format(@event, @payload.to_json, @integration)
    end
  end
end
